/*====================================================================
 
 Objectweb Browser Framework
 Copyright (C) 2000-2004 INRIA & USTL - LIFL - GOAL
 Contact: openccm@objectweb.org
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or any later version.
 
 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 USA
 
 Initial developer(s): Romain Rouvoy.
 Contributor(s): ______________________________________.
 
 ---------------------------------------------------------------------
 $Id: FcExplorerImpl.java,v 1.5 2005/09/07 13:59:14 rouvoy Exp $
 ====================================================================*/

package org.objectweb.fractal.explorer;

import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;

import javax.swing.JMenuBar;
import javax.swing.JToolBar;

import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.Interface;
import org.objectweb.fractal.api.control.BindingController;
import org.objectweb.util.explorer.api.Tree;
import org.objectweb.util.explorer.parser.api.ParserConfiguration;
import org.objectweb.util.explorer.swing.api.Explorer;
import org.objectweb.util.explorer.swing.lib.SwingExplorer;
import org.objectweb.util.trace.TraceSystem;

/**
 * This Fractal component contains the explorer
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * @version 0.1
 */
public class FcExplorerImpl
        implements BindingController, FcExplorerAttributes {

    // ==================================================================
    //
    // Internal states.
    //
    // ==================================================================

    /** The string which represents the fcAppl client */
    protected final String FC_APPL = "fcAppl";

    /** The ParserConfiguration interface to use. */
    protected ParserConfiguration parser_ = null;

    /** The Fractal Explorer. */
    protected static SwingExplorer explorer_ = null;

    /** The config files */
    protected String configFiles_ = null;

    /** The  list of Component */
    protected Map elements_ = new HashMap();

    // ==================================================================
    //
    // No internal methods.
    //
    // ==================================================================

    // ==================================================================
    //
    // Constructors.
    //
    // ==================================================================

    /**
     * Default constructor
     */
    public FcExplorerImpl() {
        // the RMI class loader does not work if there is no security manager
        //System.setSecurityManager(new SecurityManager());
        TraceSystem.setLevel("debug");
        explorer_ = new SwingExplorer("Fractal Explorer");
        parser_ = explorer_.getParserConfigurationItf();

        // Loads the Explorer Framework configuration file from the fractal-explorer Java archive.
        setConfigFiles("config/fractalProperties.xml");

        explorer_.setJMenuBar(new JMenuBar());
        explorer_.setJToolBar(new JToolBar());
        explorer_.setVisible(true);

    }

    // ==================================================================
    //
    // Public methods for interface ExplorerAttributes.
    //
    // ==================================================================

    public void setConfigFiles(String configFiles) {
        if (configFiles != null) {
            configFiles_ = configFiles;
            StringTokenizer st = new StringTokenizer(configFiles, "; ");
            while (st.hasMoreTokens()) {
                String theFile = st.nextToken();
                parser_.addPropertyFile(theFile);
            }
            parser_.parse();

            Explorer explorerItf = explorer_.getExplorerItf();
            explorerItf.setCurrentRoles(new String[] { "administrator" });
        }
    }

    public String getConfigFiles() {
        return configFiles_;
    }

    /**
     * Refreshes the tree.
     * @return the SWING representation.
     */
    public static SwingExplorer getExplorer() {
        return explorer_;
    }

    // ==================================================================
    //
    // Public methods for interface BindingController.
    //
    // ==================================================================

    public void bindFc(String clientItfName, Object sItf) {
        if (clientItfName.startsWith(FC_APPL)) {
            elements_.put(clientItfName, sItf);
            Tree treeItf = explorer_.getTreeItf();
            sItf = ((Interface) sItf).getFcItfOwner();
            treeItf.addEntry(FcExplorer.getName((Component) sItf), sItf, 1);
        }
    }

    public String[] listFc() {
        return (String[]) elements_.keySet().toArray(
                new String[elements_.size()]);
    }

    public Object lookupFc(String clientItfName) {
        if (clientItfName.startsWith(FC_APPL)) {
            return elements_.get(clientItfName);
        }
        return null;
    }

    public void unbindFc(String clientItfName) {
        if (clientItfName.equals(FC_APPL)) {
            elements_.remove(clientItfName);
        }
    }

}